@@ -44,8 +44,6 @@
 #include "qquickitem_p.h"
 #include "qquickitemchangelistener_p.h"
 
-#include <private/qqmlmemoryprofiler_p.h>
-
 #include <QtQml/qqmlengine.h>
 #include <private/qqmlengine_p.h>
 #include <private/qv4qobjectwrapper_p.h>
@@ -101,7 +99,6 @@ void QQuickViewPrivate::execute()
         component = nullptr;
     }
     if (!source.isEmpty()) {
-        QML_MEMORY_SCOPE_URL(engine.data()->baseUrl().resolved(source));
         component = new QQmlComponent(engine.data(), source, q);
         if (!component->isLoading()) {
             q->continueExecute();
@@ -136,11 +133,7 @@ void QQuickViewPrivate::itemGeometryChanged(QQuickItem *resizeItem, QQuickGeomet
 
     Typical usage:
 
-    \code
-    QQuickView *view = new QQuickView;
-    view->setSource(QUrl::fromLocalFile("myqmlfile.qml"));
-    view->show();
-    \endcode
+    \snippet qquickview-ex.cpp 0
 
     To receive errors related to loading and executing QML with QQuickView,
     you can connect to the statusChanged() signal and monitor for QQuickView::Error.
@@ -246,6 +239,21 @@ void QQuickView::setSource(const QUrl& url)
     d->execute();
 }
 
+/*!
+   Sets the initial properties \a initialProperties with which the QML
+   component gets initialized after calling \l QQuickView::setSource().
+
+   \note You can only use this function to initialize top-level properties.
+
+   \sa QQmlComponent::createWithInitialProperties()
+   \since 5.14
+*/
+void QQuickView::setInitialProperties(const QVariantMap &initialProperties)
+{
+    Q_D(QQuickView);
+    d->initialProperties = initialProperties;
+}
+
 /*!
     \internal
 
@@ -478,7 +486,9 @@ void QQuickView::continueExecute()
         return;
     }
 
-    QObject *obj = d->component->create();
+    QScopedPointer<QObject> obj(d->initialProperties.empty()
+                                ? d->component->create()
+                                : d->component->createWithInitialProperties(d->initialProperties));
 
     if (d->component->isError()) {
         const QList<QQmlError> errorList = d->component->errors();
@@ -490,7 +500,7 @@ void QQuickView::continueExecute()
         return;
     }
 
-    d->setRootObject(obj);
+    d->setRootObject(obj.take());
     emit statusChanged(status());
 }
 
@@ -508,14 +518,14 @@ void QQuickViewPrivate::setRootObject(QObject *obj)
         sgItem->setParentItem(q->QQuickWindow::contentItem());
         QQml_setParent_noEvent(sgItem, q->QQuickWindow::contentItem());
     } else if (qobject_cast<QWindow *>(obj)) {
-        qWarning() << "QQuickView does not support using windows as a root item." << endl
-                   << endl
-                   << "If you wish to create your root window from QML, consider using QQmlApplicationEngine instead." << endl;
+        qWarning() << "QQuickView does not support using windows as a root item." << Qt::endl
+                   << Qt::endl
+                   << "If you wish to create your root window from QML, consider using QQmlApplicationEngine instead." << Qt::endl;
     } else {
-        qWarning() << "QQuickView only supports loading of root objects that derive from QQuickItem." << endl
-                   << endl
-                   << "Ensure your QML code is written for QtQuick 2, and uses a root that is or" << endl
-                   << "inherits from QtQuick's Item (not a Timer, QtObject, etc)." << endl;
+        qWarning() << "QQuickView only supports loading of root objects that derive from QQuickItem." << Qt::endl
+                   << Qt::endl
+                   << "Ensure your QML code is written for QtQuick 2, and uses a root that is or" << Qt::endl
+                   << "inherits from QtQuick's Item (not a Timer, QtObject, etc)." << Qt::endl;
         delete obj;
         root = nullptr;
     }
